@@ -2,9 +2,11 @@
 
 import logging
 
+from web3.exceptions import ContractLogicError
+
 from Arbie import TransactionError
 from Arbie.Actions import Action
-from Arbie.Variables import BigNumber, PoolType
+from Arbie.Variables import BigNumber
 
 logger = logging.getLogger()
 
@@ -96,26 +98,26 @@ class SetUpTrader(Action):
         data.balance_weth(amount_weth)
 
 
-def _is_trade_uni(trade):
-    for pool in trade.pools:
-        if pool.pool_type is not PoolType.uniswap:
-            return False
-    return True
-
-
-def _perform_trade(trade, router, min_profit):
-    if not _is_trade_uni(trade):
+def _perform_trade(trade, router, min_profit, dry_run):
+    amount_out = router.check_out_given_in(trade)
+    try:
+        _, gas_cost = router.swap(trade, dry_run=True)
+    except ContractLogicError as e:
+        logger.warning(e)
         return False
 
-    amount_out = router.check_out_given_in(trade)
-    profit = amount_out - trade.amount_in
+    profit = amount_out - trade.amount_in - gas_cost
+
     logger.info(
-        f"Checking trade with profit {profit}, amount_in: {trade.amount_in}, amount out: {amount_out}"
+        f"Checking trade with profit {profit}, amount_in: {trade.amount_in}, amount out: {amount_out}, gas cost: {gas_cost}"
     )
-    if profit > min_profit:
-        logger.info(f"Executing trade {trade}")
-        return router.swap(trade)
-    return False
+    if profit < min_profit:
+        return False
+
+    logger.info(f"Executing trade {trade}")
+    if dry_run:
+        return False
+    return router.swap(trade)
 
 
 def perform_trade(data, amount_weth):
@@ -124,7 +126,7 @@ def perform_trade(data, amount_weth):
     for trade in data.trades():
         # Make sure that we don't try to trade with more weth then we have
         trade.amount_in = min(trade.amount_in, amount_weth)
-        if _perform_trade(trade, router, min_profit):
+        if _perform_trade(trade, router, min_profit, data.dry_run()):
             return True
     return False
 
@@ -142,6 +144,7 @@ class Trader(Action):
         min_profit: 0.3
         weth: weth
         account: account
+        dry_run: True
     output:
         profit: profit
     """
@@ -154,58 +157,9 @@ class Trader(Action):
         logger.info(f"amount_eth: {amount_eth}, amount_weth: {amount_weth}")
 
         if not perform_trade(data, amount_weth):
-            raise Exception("No trade performed")
+            logger.warning("No trade opportunity found.")
 
         balance_post = await balance_checker.check_total(trader_account.address)
 
         data.profit(balance_post - balance_pre)
         logger.info("Finished trading")
-
-
-class LogTrader(Action):
-    """Log arbitrage opportunity for a list sorted trades.
-
-    Remove all trades that are not profitable.
-
-    [Settings]
-    input:
-        web3: web3
-        router: router
-        trades: filtered_trades
-        min_profit: 0.3
-        weth: weth
-    output:
-        profit_per_trade: profit_per_trade
-        profit: profit
-    """
-
-    async def on_next(self, data):  # noqa: WPS210
-        value = self.log_trade(data)
-        profit = sum(value)
-        profit_per_trade = profit / len(value)
-
-        logger.info(f"Total profit: {profit}, profit per trade: {profit_per_trade}")
-
-        data.profit_per_trade(profit_per_trade)
-        data.profit(profit)
-
-        logger.info("Finished trading")
-
-    def log_trade(self, data):
-        router = data.router()
-        min_profit = data.min_profit()
-        profits = []
-        for trade in data.trades():
-            profit = self._log_trade(trade, router, min_profit)
-            if profit:
-                profits.append(profit)
-        return profits
-
-    def _log_trade(self, trade, router, min_profit):
-        amount_out = router.check_out_given_in(trade)
-        profit = amount_out - trade.amount_in
-        if profit > min_profit:
-            logger.info(
-                f"Executing trade with profit {profit}, amount_in: {trade.amount_in}, amount out: {amount_out}"
-            )
-            return profit
