@@ -3,7 +3,8 @@ from typing import List
 
 import pytest
 
-from Arbie.Variables import Pool, Token
+from Arbie.address import dummy_token_generator
+from Arbie.Variables import Pool, PoolType, Token
 
 small = 10000
 medium = 1000000
@@ -12,22 +13,22 @@ large = 100000000
 
 @pytest.fixture
 def eth() -> Token:
-    return Token("eth", 1)
+    return dummy_token_generator("eth", 1)
 
 
 @pytest.fixture
 def dai() -> Token:
-    return Token("dai", 300)
+    return dummy_token_generator("dai", 300)
 
 
 @pytest.fixture
 def btc() -> Token:
-    return Token("btc", 3.0 / 100)
+    return dummy_token_generator("btc", 3.0 / 100)
 
 
 @pytest.fixture
 def yam() -> Token:
-    return Token("yam", 3000)
+    return dummy_token_generator("yam", 3000)
 
 
 @pytest.fixture
@@ -37,14 +38,28 @@ def pools(dai, eth, btc, yam) -> List[Pool]:
             [eth, dai, yam],
             [small / 303.0, small / 0.9, small / 0.1],
             [1 / 3.0, 1 / 3.0, 1 / 3.0],
+            PoolType.uniswap,
             0.004,
         ),
-        Pool([eth, btc], [large / 305.0, large / 10000], [5 / 6, 1 / 6], 0.01),
+        Pool(
+            [eth, btc],
+            [large / 305.0, large / 10000],
+            [5 / 6, 1 / 6],
+            PoolType.uniswap,
+            0.01,
+        ),
         Pool(
             [eth, dai, btc],
             [medium / 301.0, medium / 1.1, medium / 10020],
             [1 / 2.0, 1 / 4.0, 1 / 4.0],
+            PoolType.uniswap,
             0.004,
         ),
-        Pool([dai, yam], [small / 1.1, small / 0.1], [1 / 2.0, 1 / 2.0], 0.001),
+        Pool(
+            [dai, yam],
+            [small / 1.1, small / 0.1],
+            [1 / 2.0, 1 / 2.0],
+            PoolType.balancer,
+            0.001,
+        ),
     ]
